engine

package
v0.7.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 15, 2026 License: MIT Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Config

type Config struct {
	Method      string
	URL         string
	Body        string
	Headers     []string
	Cookies     string
	Proxy       string
	Timeout     int
	FollowRedir bool
}

Config do engine

type FuzzResult

type FuzzResult struct {
	Payload  mutator.Payload
	Point    input.InjectionPoint
	Response Response
	Error    error
}

FuzzResult - resultado de um request fuzzado

func Fuzz

func Fuzz(cfg Config, points []input.InjectionPoint, payloads []mutator.Payload, concurrency, delayMs, rateLimit int, verbose bool) []FuzzResult

Fuzz executes all payloads against injection points with concurrency

type Response

type Response struct {
	StatusCode  int
	Status      string
	Headers     http.Header
	Body        string
	BodyLength  int
	TimeMs      int64
	ContentType string
}

Response capturada

func CaptureBaseline

func CaptureBaseline(cfg Config) (*Response, error)

CaptureBaseline envia o request original e captura a resposta de referência

Jump to