Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BlindConfirmer ¶
BlindConfirmer performs statistical confirmation of blind injection findings
func NewBlindConfirmer ¶
func NewBlindConfirmer(cfg engine.Config) *BlindConfirmer
NewBlindConfirmer creates a confirmer with defaults
func (*BlindConfirmer) ConfirmBoolean ¶
func (bc *BlindConfirmer) ConfirmBoolean(cfg engine.Config, truePayload, falsePayload mutator.Payload) bool
ConfirmBoolean sends true and false payloads and compares body lengths
func (*BlindConfirmer) ConfirmTimeBased ¶
func (bc *BlindConfirmer) ConfirmTimeBased(cfg engine.Config, payload mutator.Payload, sleepSec int) (bool, float64)
ConfirmTimeBased sends the payload multiple times and compares with a zero-delay variant
Click to show internal directories.
Click to hide internal directories.